@@ -617,7 +617,8 @@ class BlockStateMachine(object):
                 elif ch == '{':
                     self.state = BSM_IN_BLOCK
                 else:
-                    self._error('Junk at C{}'.format(pos))
+                    self._error(line_num, uni_line,
+                                u'Junk at C{}'.format(pos))
             elif self.state == BSM_IN_BLOCK:
                 self._error('Junk at C{}'.format(pos))
         self.problems.extend(self._ism.problems)
